<?php

namespace Litecms\Transactioninsert\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Transactioninsert\Models\Transactioninsert;

class TransactioninsertPolicy
{

    /**
     * Determine if the given user can view the transactioninsert.
     *
     * @param UserPolicy $user
     * @param Transactioninsert $transactioninsert
     *
     * @return bool
     */
    public function view(UserPolicy $user, Transactioninsert $transactioninsert)
    {
        if ($user->canDo('transactioninsert.transactioninsert.view') && $user->isAdmin()) {
            return true;
        }

        return $transactioninsert->user_id == user_id() && $transactioninsert->user_type == user_type();
    }

    /**
     * Determine if the given user can create a transactioninsert.
     *
     * @param UserPolicy $user
     * @param Transactioninsert $transactioninsert
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('transactioninsert.transactioninsert.create');
    }

    /**
     * Determine if the given user can update the given transactioninsert.
     *
     * @param UserPolicy $user
     * @param Transactioninsert $transactioninsert
     *
     * @return bool
     */
    public function update(UserPolicy $user, Transactioninsert $transactioninsert)
    {
        if ($user->canDo('transactioninsert.transactioninsert.edit') && $user->isAdmin()) {
            return true;
        }

        return $transactioninsert->user_id == user_id() && $transactioninsert->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given transactioninsert.
     *
     * @param UserPolicy $user
     * @param Transactioninsert $transactioninsert
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Transactioninsert $transactioninsert)
    {
        return $transactioninsert->user_id == user_id() && $transactioninsert->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given transactioninsert.
     *
     * @param UserPolicy $user
     * @param Transactioninsert $transactioninsert
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Transactioninsert $transactioninsert)
    {
        if ($user->canDo('transactioninsert.transactioninsert.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given transactioninsert.
     *
     * @param UserPolicy $user
     * @param Transactioninsert $transactioninsert
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Transactioninsert $transactioninsert)
    {
        if ($user->canDo('transactioninsert.transactioninsert.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
